<TS language="cs" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>O Gridcoinu</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Vytvoř novou adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nová</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Zkopíruj tuto adresu do systémové schránky</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopíruj</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Ov??it správu</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Smaž tuto adresu ze seznamu</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Kniha adres</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;maž</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopíruj &amp;označení</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Uprav</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Označení</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez označení)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Změna hesla</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Zadej platné heslo</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Zadej nové heslo</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Totéž heslo ještě jednou</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Zadej nové heslo k peněžence.&lt;br/&gt;Použij &lt;b&gt;alespoň deset náhodných znaků&lt;/b&gt; nebo &lt;b&gt;alespoň osm slov&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Zašifruj peněženku</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>K provedení této operace musíš zadat heslo k peněžence, aby se mohla odemknout.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Odemkni peněženku</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Změň heslo</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Zadej staré a nové heslo k pen?žence.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrď zašifrování peněženky</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Jsi si jistý, že chceš peněženku zašifrovat?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Peněženka je zašifrována</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>DŮLEŽITÉ: Všechny předchozí zálohy peněženky by měly být nahrazeny nově vygenerovanou, zašifrovanou peněženkou. Z bezpečnostních důvodů budou předchozí zálohy nešifrované peněženky nepoužitelné, jakmile začneš používat novou zašifrovanou peněženku.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Zašifrování peněženky selhalo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Zašifrování peněženky selhalo kvůli vnitřní chybě. Tvá peněženka tedy nebyla zašifrována.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Zadaná hesla nejsou shodná.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Nepodařilo se odemknout peněženku</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Nezadal jsi správné heslo pro dešifrování peněženky.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Heslo k peněžence bylo v pořádku změněno.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Upozornění: Caps Lock je zapnutý!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Peněženka</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Přehled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Zobraz celkový přehled peněženky</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>P&amp;ošli</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Při&amp;jmi</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Procházej historii transakcí</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Konec</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Ukonči aplikaci</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Možnosti...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Zobraz/Skryj</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Zaši&amp;fruj peněženku...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Změň &amp;heslo...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Změň heslo k šifrování peněženky</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Po&amp;depiš zprávu...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Ověř zprávu...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Ladicí okno</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Otevři ladicí a diagnostickou konzoli</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápověd&amp;a</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Aktuální</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Stahuji...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Odeslané transakce</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Příchozí transakce</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Peněženka je &lt;b&gt;zašifrovaná&lt;/b&gt; a momentálně &lt;b&gt;zamčená&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Upozorn?ní sít?</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Počet:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtů:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Částka:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Poplatek:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Čistá částka:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Drobné:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Částka</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Potvrzení</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrzeno</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopíruj adresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopíruj její označení</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopíruj částku</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopíruj ID transakce</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopíruj počet</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopíruj poplatek</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopíruj čistou částku</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopíruj bajty</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopíruj drobné</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ano</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez označení)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>drobné z %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(drobné)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Uprav adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Označení</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nová přijímací adresa</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nová odesílací adresa</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Uprav přijímací adresu</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Uprav odesílací adresu</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Zadaná adresa „%1“ už v adresáři je.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nemohu odemknout peněženku.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Nepodařilo se mi vygenerovat nový klíč.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Hlavní</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Síť</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Namapovat port přes &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>Por&amp;t:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port proxy (např. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Zav?ením se aplikace minimalizuje. Pokud je tato volba zaškrtnuta, tak se aplikace ukon?í pouze zvolením Konec v menu.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>Ukazo&amp;vat adresy ve výpisu transakcí</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>O&amp;kno</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Po minimalizaci okna zobrazí pouze ikonu v panelu.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimalizovávat do ikony v panelu</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>Za&amp;vřením minimalizovat</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>Zobr&amp;azení</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Jazyk uživatelského rozhraní:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Je&amp;dnotka pro částky:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Zvol výchozí podjednotku, která se bude zobrazovat v programu a při posílání mincí.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Budiž</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <source>default</source>
        <translation>výchozí</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Zadaná adresa proxy je neplatná.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>K dispozici:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Aktuální disponibilní stav tvého účtu</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nedozráno:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Celkem:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Celkový stav tvého účtu</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>nedostupná informace</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Verze klienta</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informace</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Čas spuštění</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Počet spojení</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Řetězec bloků</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Aktuální počet bloků</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Čas posledního bloku</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Vyčistit</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzole</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Síťový provoz</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Součty</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Sem:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Ven:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Soubor s ladicími záznamy</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Vyčistit konzoli</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Odhad celkového po?tu blok?</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Název klienta</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>V historii se pohybuješ šipkami nahoru a dolů a pomocí &lt;b&gt;Ctrl-L&lt;/b&gt; čistíš obrazovku.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Napsáním &lt;b&gt;help&lt;/b&gt; si vypíšeš přehled dostupných příkazů.</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 kB</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Pošli mince</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Vstupy...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automaticky vybrané</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Nedostatek prostředků!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Počet:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bajtů:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Částka:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Poplatek:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Čistá částka:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Pošli více příjemcům naráz</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Při&amp;dej příjemce</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Všechno s&amp;maž</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Potvrď odeslání</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Pošl&amp;i</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopíruj počet</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopíruj částku</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopíruj poplatek</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopíruj čistou částku</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopíruj bajty</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopíruj drobné</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Potvrď odeslání mincí</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Adresa p?íjemce je neplatná, p?ekontroluj ji prosím.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Odesílaná částka musí být větší než 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Částka překračuje stav účtu.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Celková částka při připočítání poplatku %1 překročí stav účtu.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Zaznamenána duplikovaná adresa; každá adresa m?že být v odesílané platb? pouze jednou.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez označení)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Čás&amp;tka:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Komu:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Zpráva:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>O&amp;značení:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Vlož adresu ze schránky</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Zadej označení této adresy; obojí se ti pak uloží do adresáře</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Podpisy - podepsat/ověřit zprávu</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Podepiš zprávu</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Podepsáním zprávy svými adresami m?žeš prokázat, že je skute?n? vlastníš. Bu? opatrný a nepodepisuj nic vágního; nap?íklad p?i phishingových útocích m?žeš být lákán, abys n?co takového podepsal. Podepisuj pouze zcela úplná a detailní prohlášení, se kterými souhlasíš.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Vlož adresu ze schránky</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Sem vepiš zprávu, kterou chceš podepsat</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Zkopíruj tento podpis do schránky</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Po&amp;depiš zprávu</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Vymaž všechna pole formuláře pro podepsání zrávy</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Všechno &amp;smaž</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Ověř zprávu</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>K ov??ení podpisu zprávy zadej podepisující adresu, zprávu (ov?? si, že správn? kopíruješ zalomení ?ádk?, mezery, tabulátory apod.) a podpis. Dávej pozor na to, abys nezkopíroval do podpisu víc, než co je v samotné podepsané zpráv?, abys nebyl napálen man-in-the-middle útokem.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Vymaž všechna pole formuláře pro ověření zrávy</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Kliknutím na „Podepiš zprávu“ vygeneruješ podpis</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Zadaná adresa je neplatná.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Zkontroluj ji prosím a zkus to pak znovu.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Zadaná adresa nepasuje ke klíči.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Odemčení peněženky bylo zrušeno.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Soukromý klíč pro zadanou adresu není dostupný.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Nepodařilo se podepsat zprávu.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Zpráva podepsána.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Podpis nejde dekódovat.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Zkontroluj ho prosím a zkus to pak znovu.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Podpis se neshoduje s hašem zprávy.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Nepodařilo se ověřit zprávu.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Zpráva ověřena.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Otřevřeno dokud %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nepotvrzeno</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 potvrzení</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, ještě nebylo rozesláno</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>neznámo</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Pro</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>vlastní adresa</translation>
    </message>
    <message>
        <source>label</source>
        <translation>označení</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Příjem</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>neakceptováno</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Výdaj</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transakční poplatek</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Čistá částka</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentář</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Částka</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detaily transakce</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Toto okno zobrazuje detailní popis transakce</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>?ástka</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Otřevřeno dokud %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Nepotvrzeno</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Potvrzeno (%1 potvrzení)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>V kolizi</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Vygenerováno, ale neakceptováno</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Přijato do</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Přijato od</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Posláno na</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Platba sama sobě</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Stav transakce. Najetím myši na toto políčko si zobrazíš počet potvrzení.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum a čas přijetí transakce.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Druh transakce.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Cílová adresa transakce.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Částka odečtená z nebo přičtená k účtu.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Tento týden</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Tento měsíc</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Minulý měsíc</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Letos</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Rozsah...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Přijato</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Posláno</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Sám sobě</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Vytěženo</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostatní</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimální částka</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopíruj adresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopíruj její označení</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopíruj částku</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopíruj ID transakce</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Uprav označení</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Zobraz detaily transakce</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrzeno</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Označení</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>?ástka</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rozsah:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>až</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>P?i nastavování naslouchacího RPC portu %u pro IPv6 nastala chyba, vracím se k IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>P?i nastavování naslouchacího RPC portu %u pro IPv4 nastala chyba: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Užití:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Výpis p?íkaz?</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Získat nápov?du pro p?íkaz</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Upozorn?ní: -paytxfee je nastaveno velmi vysoko! Toto je transak?ní poplatek, který zaplatíš za každou poslanou transakci.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Upozorn?ní: soubor wallet.dat je poškozený, data jsou však zachrán?na! P?vodní soubor wallet.dat je uložený jako wallet.{timestamp}.bak v %s. Pokud je stav tvého ú?tu nebo transakce nesprávné, z?ejm? bys m?l obnovit zálohu.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Upozorn?ní: nastala chyba p?i ?tení souboru wallet.dat! Všechny klí?e se p?e?etly správn?, ale data o transakcích nebo záznamy v adresá?i mohou chyb?t ?i být nesprávné.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Nepodařilo se naslouchat na žádném portu. Použij -listen=0, pokud to byl tvůj záměr.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>K použití volby %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Musíš nastavit rpcpassword=&lt;heslo&gt; v konfigura?ním souboru:
%s
Pokud konfigura?ní soubor ješt? neexistuje, vytvo? ho tak, aby ho mohl ?íst pouze vlastník.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Neplatná ?ástka pro -paytxfee=&lt;?ástka&gt;: '%s'</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>Soubor wallet.dat je poškozen, jeho záchrana se nezda?ila</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Neplatná -proxy adresa: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Nemohu p?eložit -bind adresu: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Nemohu p?eložit -externalip adresu: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Chyba p?i na?ítání wallet.dat: pen?ženka je poškozená</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Chyba p?i na?ítání wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Načítám adresy...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Neda?í se mi p?ipojit na %s na tomhle po?íta?i (operace bind vrátila chybu %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Neplatná ?ástka</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>V -onlynet byla uvedena neznámá síť: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedostatek prostředků</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Načítám index bloků...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Načítám peněženku...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nemohu napsat výchozí adresu</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Přeskenovávám…</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Načítání dokončeno</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
</TS>